aboutsummaryrefslogtreecommitdiff
path: root/engines/prince/script.h
diff options
context:
space:
mode:
authorlukaslw2014-05-30 23:36:49 +0200
committerlukaslw2014-06-22 20:08:26 +0200
commit4be66f5110a84bc4d6b8444e80fc846dbb88340b (patch)
tree90851d2e91236ce72f87bb3f4ee2c3c7454882eb /engines/prince/script.h
parent16a6d99a861c75ff2a142cc604b5ea9d87063072 (diff)
downloadscummvm-rg350-4be66f5110a84bc4d6b8444e80fc846dbb88340b.tar.gz
scummvm-rg350-4be66f5110a84bc4d6b8444e80fc846dbb88340b.tar.bz2
scummvm-rg350-4be66f5110a84bc4d6b8444e80fc846dbb88340b.zip
PRINCE: Rename Overlay to Mask, loadAllMasks update
Diffstat (limited to 'engines/prince/script.h')
-rw-r--r--engines/prince/script.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/prince/script.h b/engines/prince/script.h
index d0693ca11f..4b9f85a61e 100644
--- a/engines/prince/script.h
+++ b/engines/prince/script.h
@@ -39,7 +39,7 @@ class PrinceEngine;
class Animation;
struct Anim;
struct BackgroundAnim;
-struct Overlay;
+struct Mask;
namespace Detail {
template <typename T> T LittleEndianReader(void *data);
@@ -54,7 +54,7 @@ public:
int _mobs; // mob flag offset
int _backAnim; // offset to array of animation numbers
int _obj; // offset to array of object numbers
- int _nak; // offset to array of overlays
+ int _nak; // offset to array of masks
int _itemUse;
int _itemGive;
int _walkTo; // offset to array of WALKTO events or 0
@@ -135,7 +135,7 @@ public:
uint8 *getRoomOffset(int locationNr);
void installBackAnims(Common::Array<BackgroundAnim> &_backanimList, int offset);
void installSingleBackAnim(Common::Array<BackgroundAnim> &_backanimList, int offset);
- void loadOverlays(Common::Array<Overlay> &overlayList, int offset);
+ bool loadAllMasks(Common::Array<Mask> &maskList, int offset);
const char *getString(uint32 offset) {
return (const char *)(&_data[offset]);